@@ -28,10 +28,10 @@ def k_truss(G: Graph, k) -> Graph:
             S = C
 
     # Remove isolate nodes
-    indices, _ = C.reduce_rowwise(monoid.any).to_values()
+    indices, _ = C.reduce_rowwise(monoid.any).to_coo()
     Ktruss = C[indices, indices].new()
 
     # Convert back to networkx graph with correct node ids
     keys = G.list_to_keys(indices)
     key_to_id = dict(zip(keys, range(len(indices))))
-    return Graph.from_graphblas(Ktruss, key_to_id=key_to_id)
+    return Graph(Ktruss, key_to_id=key_to_id)
