@@ -1,5 +1,6 @@
 from collections import defaultdict
 
+import graphblas as gb
 from graphblas import Matrix, Vector, binary, replace, select, unary
 
 import graphblas_algorithms as ga
@@ -415,7 +416,7 @@ def to_directed_graph(G, weight=None, dtype=None):
     if isinstance(G, DiGraph):
         return G
     try:
-        return DiGraph.from_graphblas(G)
+        return DiGraph(G)
     except TypeError:
         pass
 
@@ -435,7 +436,7 @@ def to_graph(G, weight=None, dtype=None):
         return G
     try:
         # Should we check if it can be undirected?
-        return DiGraph.from_graphblas(G)
+        return DiGraph(G)
     except TypeError:
         pass
 
@@ -538,22 +539,28 @@ class DiGraph(Graph):
     }
     graph_attr_dict_factory = dict
 
-    def __init__(self, incoming_graph_data=None, **attr):
+    def __init__(self, incoming_graph_data=None, *, key_to_id=None, **attr):
         if incoming_graph_data is not None:
-            raise NotImplementedError("incoming_graph_data is not None")
+            # Does not copy if A is a Matrix!
+            A = gb.core.utils.ensure_type(incoming_graph_data, Matrix)
+            if A.nrows != A.ncols:
+                raise ValueError(f"Adjacency matrix must be square; got {A.nrows} x {A.ncols}")
+        else:
+            A = Matrix()
         self.graph_attr_dict_factory = self.graph_attr_dict_factory
         self.graph = self.graph_attr_dict_factory()  # dictionary for graph attributes
         self.graph.update(attr)
 
         # Graphblas-specific properties
-        self._A = Matrix()
-        self._key_to_id = {}
+        self._A = A
+        if key_to_id is None:
+            key_to_id = {i: i for i in range(A.nrows)}
+        self._key_to_id = key_to_id
         self._id_to_key = None
         self._cache = {}
 
     # Graphblas-specific methods
     from_networkx = classmethod(_utils.from_networkx)
-    from_graphblas = classmethod(_utils.from_graphblas)
     id_to_key = property(_utils.id_to_key)
     get_property = _utils.get_property
     get_properties = _utils.get_properties
@@ -586,6 +593,10 @@ class DiGraph(Graph):
         self._A.name = s
         self.graph["name"] = s
 
+    @property
+    def matrix(self):
+        return self._A
+
     def __iter__(self):
         return iter(self._key_to_id)
 
